@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 """Update Class file."""
 
+import datetime
 import dateutil.parser
 import logging
+import pytz
 import sys
 
 from bits.github import GitHub
@@ -416,7 +418,20 @@ class Update(object):
 
         # get team syncs from source of truth - bitsdb mongo
         m = self.auth.mongo()
-        mongo_team_syncs = m.get_collection('github_team_sync')
+
+        tz = pytz.timezone('UTC')
+        mongo_team_syncs = []
+        syncs_dict = {}
+        for sync in m.get_collection('github_team_sync'):
+            created = sync['created']
+            modified = sync['modified']
+            if isinstance(created, str):
+                sync['created'] = datetime.datetime.strptime(created, '%Y-%b-%d %H:%M:%S').astimezone(tz)
+            if isinstance(modified, str):
+                sync['modified'] = datetime.datetime.strptime(modified, '%Y-%b-%d %H:%M:%S').astimezone(tz)
+            mongo_team_syncs.append(sync)
+            syncs_dict[sync['_id']] = sync
+        m.update_collection('github_team_sync', syncs_dict)
         print('Found {} GitHub Team Syncs in BITSdb Mongo.'.format(len(mongo_team_syncs)))
 
         # create new dict of team syncs ready for datastore and firestore
@@ -487,7 +502,7 @@ class Update(object):
         )
 
         # update firestore in the github app projects
-        print(g.firestore(firestore_project).update_collection_batch(
+        print(g.firestore(firestore_project).update_collection(
             'team_syncs',
             firestore_syncs,
             delete_docs=True,
